@@ -305,7 +305,7 @@ class Client(commandServer, encrypt, Desktop):
             return p.success()
         else:
             p = process(mountCmd, "-t", "cifs", "-o",
-                        "cache=%s,domain=%s,vers=%s,user=%s%s" % (cache_method,
+                        "cache=%s,domain=%s,user=%s%s" % (cache_method,
                             domain, userName, nomapposix),
                         "//%s/%s" % (host, res), rpath,
                         envdict={"PASSWD": userPwd}, stderr=STDOUT)
